@@ -26,8 +26,8 @@ public slots:
 	void deleteSelectedNotes();
 	void copySelectedNotes();
 	void moveSelectedNotes();
-    void addSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(++m_iSelectedCount)); }
-    void subSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(--m_iSelectedCount)); }
+    void addSelectedCount() { m_lSelectedCount.setText(QString(trUtf8("%1 notes")).arg(++m_iSelectedCount)); }
+    void subSelectedCount() { m_lSelectedCount.setText(QString(trUtf8("%1 notes")).arg(--m_iSelectedCount)); }
 
 private:
     Ui::QDeleteNotesViewClass ui;
