@@ -63,13 +63,13 @@ public:
 		area.setWidget(&areaWidget);
 		area.setWidgetResizable(true);
 		mainLayout->addWidget(&area);
-		setWindowTitle("Choose contact");
+		setWindowTitle(trUtf8("Choose contact"));
 
 		QObject::connect(&listWidget, SIGNAL(itemClicked(QListWidgetItem *)), SLOT(selectContactEmail(QListWidgetItem *)));
 
 		setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 		QtConcurrent::run(loadContactListCallback, this);
-		resize(800, 400);
+		resize(800, 480);
 	}
 
 	QString getSelectedEmail() { return selectedEmail; }
