@@ -32,7 +32,7 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent)
 
 	if(isNewNote)
 	{
-		this->setWindowTitle("Edit note - Untitled");
+		this->setWindowTitle(trUtf8("Edit note - Untitled"));
 		//ui.wvNoteEdit->setHtml("<html><head/><body>&nbsp; </body></html>");
 	}
 	else
@@ -83,10 +83,11 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent)
 	QAction* actAddTag = new QAction(QIcon(":/IconAdd/general_tag.png"), "Add tag", this);
 	QAction* actAttachFile = new QAction(QIcon(":/IconAdd/email_attachment.png"), "Attach file", this);
 	QAction* actEmailNote = new QAction(/*QIcon(":/IconAdd/general_email.png"),*/ "Email note", this);
+	QAction* actGps = new QAction(QIcon(":/IconAdd/gps_location.png"), "Location", this);
 	QAction* actSaveNote = new QAction(QIcon(":/IconAdd/notes_save.png"), "Save note", this);
 
-	QAction* actZoomin = new QAction(QIcon(":/IconAdd/note_zoomin.png"), "Zoom In", this);
-	QAction* actZoomout = new QAction(QIcon(":/IconAdd/note_zoomout.png"), "Zoom Out", this);
+	//QAction* actZoomin = new QAction(QIcon(":/IconAdd/note_zoomin.png"), "Zoom In", this);
+	//QAction* actZoomout = new QAction(QIcon(":/IconAdd/note_zoomout.png"), "Zoom Out", this);
 
 	actBold->setCheckable(true);
 	actItalic->setCheckable(true);
@@ -99,6 +100,7 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent)
 	htmlEditToolbar->addAction(actAddTodo);
 	htmlEditToolbar->addAction(actAttachFile);
 	htmlEditToolbar->addAction(actAddTag);
+	htmlEditToolbar->addAction(actGps);
 	htmlEditToolbar->addAction(actSaveNote);
 	//htmlEditToolbar->addAction(actZoomin);
 	//htmlEditToolbar->addAction(actZoomout);
@@ -127,9 +129,9 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent)
 	QObject::connect(actBullets, SIGNAL(triggered()), this, SLOT(addBullet()));
 	QObject::connect(actAttachFile, SIGNAL(triggered()), this, SLOT(attachFile()));
 	QObject::connect(actAddTodo, SIGNAL(triggered()), this, SLOT(insertTodo()));
-
-	QObject::connect(actZoomin, SIGNAL(triggered()), this, SLOT(zoominView()));
-	QObject::connect(actZoomout, SIGNAL(triggered()), this, SLOT(zoomoutView()));
+	QObject::connect(actGps, SIGNAL(triggered()), this, SLOT(startGpsLocationUpdate()));
+	//QObject::connect(actZoomin, SIGNAL(triggered()), this, SLOT(zoominView()));
+	//QObject::connect(actZoomout, SIGNAL(triggered()), this, SLOT(zoomoutView()));
 
 	//QObject::connect(ui.wvNoteEdit, SIGNAL(textEdited(const QString&)), SLOT(setDirtyData()));
 	QObject::connect(ui.leNoteTitle, SIGNAL(textEdited(const QString&)), SLOT(setDirtyData()));
@@ -142,6 +144,8 @@ QNoteEditWindow::~QNoteEditWindow()
 {
 #ifdef Q_WS_MAEMO_5
 	delete supressor;
+	if(source)
+		delete source;
 #endif
 }
 
@@ -149,7 +153,7 @@ void QNoteEditWindow::hideEvent(QHideEvent* e)
 {
 	if(hasDirtyData)
 	{
-		if(QMessageBox::question(this, "Save note", "Note has been modified. Save it now?", QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes)
+		if(QMessageBox::question(this, trUtf8("Save note"), trUtf8("Note has been modified. Save it now?"), QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes)
 		{
 			saveNote();
 		}
@@ -190,7 +194,7 @@ void QNoteEditWindow::saveNote()
 
 	if(m_Note.title.empty())
 	{
-		displayError("Unable to save note", "Title cannot be empty");
+		displayError(trUtf8("Unable to save note"), trUtf8("Title cannot be empty"));
 		setProgressIndicator(false);
 	}
 	else
@@ -213,11 +217,11 @@ void QNoteEditWindow::noteSaveFailure()
 {
 	if(isNewNote)
 	{
-		displayError("Failed to save note", QString(m_hEvernote->getLastErrorString().c_str()));
+		displayError(trUtf8("Failed to save note"), QString(m_hEvernote->getLastErrorString().c_str()));
 	}
 	else
 	{
-		displayError("Failed to update note", QString(m_hEvernote->getLastErrorString().c_str()));
+		displayError(trUtf8("Failed to update note"), QString(m_hEvernote->getLastErrorString().c_str()));
 	}
 
 	setProgressIndicator(false);
@@ -263,9 +267,9 @@ void QNoteEditWindow::attachFile()
 	QFileDialog::Options options;
 	QString selectedFilter;
 	QString fileName = QFileDialog::getOpenFileName(this,
-			tr("Choose file"),
+			trUtf8("Choose file"),
 			"/",
-			tr("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"),
+			trUtf8("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"),
 			&selectedFilter,
 			options);
 
@@ -294,7 +298,7 @@ void QNoteEditWindow::attachFile()
 		}
 	}
 	//QByteArray content = QHtmlContentHandler::getStoredContent(fileName, contentType);
-	qDebug() << "Tag" << htmlTag;
+	//qDebug() << "Tag" << htmlTag;
 	//ui.wvNoteEdit->page()->
 
 	//QString newHtml = ui.wvNoteEdit->page()->mainFrame()->toHtml().replace("</body></html>",
@@ -357,16 +361,16 @@ void QNoteEditWindow::loadResource(QUrl url)
 	{
 		QString fileName = QFileDialog::getSaveFileName(
 				this,
-				tr("Save resource"),
+				trUtf8("Save resource"),
 		        "/MyDocs/" + QString::fromStdString(r.attributes.fileName),
-		        tr("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"));
+		        trUtf8("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"));
 
 		if(fileName.size() > 0)
 		{
 			QFile file(fileName);
 			if (!file.open(QIODevice::WriteOnly))
 			{
-				displayError("Cannot write file", file.errorString());
+				displayError(trUtf8("Cannot write file"), file.errorString());
 				return;
 			}
 
@@ -378,7 +382,7 @@ void QNoteEditWindow::loadResource(QUrl url)
 	}
 	else
 	{
-		displayError("Failed to load resource", QString::fromStdString(m_hEvernote->getLastErrorString()));
+		displayError(trUtf8("Failed to load resource"), QString::fromStdString(m_hEvernote->getLastErrorString()));
 	}
 	setProgressIndicator(false);
 }
@@ -396,9 +400,9 @@ void QNoteEditWindow::setChecked(int tagId)
 {
 	QWebElement inputElem =  ui.wvNoteEdit->page()->mainFrame()->documentElement().findFirst("input[id=\"" + QString::number(tagId) + "\"]");
 
-	qDebug() << __FUNCTION__ << "Tag:" << inputElem.tagName();
+	//qDebug() << __FUNCTION__ << "Tag:" << inputElem.tagName();
 	QWebElement tagTodoElem = inputElem.parent();
-	qDebug() << __FUNCTION__ << "Tag:" << tagTodoElem.tagName();
+	//qDebug() << __FUNCTION__ << "Tag:" << tagTodoElem.tagName();
 
 	if(tagTodoElem.attribute("checked") == "false")
 		tagTodoElem.setAttribute("checked", "true");
@@ -406,6 +410,7 @@ void QNoteEditWindow::setChecked(int tagId)
 		tagTodoElem.setAttribute("checked", "false");
 }
 
+/*
 void QNoteEditWindow::zoominView()
 {
 	ui.wvNoteEdit->setZoomFactor(ui.wvNoteEdit->zoomFactor()+0.1);
@@ -415,3 +420,35 @@ void QNoteEditWindow::zoomoutView()
 {
 	ui.wvNoteEdit->setZoomFactor(ui.wvNoteEdit->zoomFactor()-0.1);
 }
+*/
+
+void QNoteEditWindow::startGpsLocationUpdate()
+{
+#ifdef Q_WS_MAEMO_5
+	source = QGeoPositionInfoSource::createDefaultSource(this);
+	if (source)
+	{
+		connect(source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(positionUpdated(QGeoPositionInfo)));
+	    source->setUpdateInterval(5000);
+	    source->startUpdates();
+	    displayInformationBox(trUtf8("GPS position search started. Please wait..."));
+	}
+#else
+	QMessageBox::critical(this, "Error", "Maemo5 specific code");
+#endif
+}
+
+#ifdef Q_WS_MAEMO_5
+void QNoteEditWindow::positionUpdated(const QGeoPositionInfo& update)
+{
+	m_Note.attributes.latitude = update.coordinate().latitude();
+	m_Note.attributes.longitude = update.coordinate().longitude();
+
+	qDebug() << m_Note.attributes.latitude << m_Note.attributes.longitude;
+
+	displayInformationBox(trUtf8("GPS position updated"));
+	source->stopUpdates();
+	delete source;
+	source = NULL;
+}
+#endif
