@@ -26,12 +26,14 @@ public:
 public slots:
     void startEditor();
     void resizeWebView();
-    void loadResource(QUrl);
+    void openLink(QUrl);
+
     void zoominView();
     void zoomoutView();
     void emailNote();
     void loadNextNote();
     void loadPrevNote();
+    void showNoteMap();
 
     bool loadNote();
     void displayNote();
@@ -45,9 +47,15 @@ public slots:
 
     void onFavoriteClicked();
     void backgroundLoad();
+    void startBackgroundTask() { m_pBackgroundJob->start(); }
+    void noteLoadFinished();
+
+    /* JS API functions */
+    void handleResource(QString);
+
     bool backgroundJobCallback() { return loadNote(); }
     void jobDoneCallback() { displayNote(); }
-    void jobFailedCallback() { displayError("Unable to load note", QString(m_hEvernote->getLastErrorString().c_str())); }
+    void jobFailedCallback() { displayError(trUtf8("Unable to load note"), QString(m_hEvernote->getLastErrorString().c_str())); }
 
 signals:
     void startEditorSignal(Note&, QEnmlReader*);
@@ -55,13 +63,14 @@ signals:
 private:
 	void clearNote();
 	void initNavigationControls();
+	void updateHeader();
 
 private:
     Ui::QNoteViewWindowClass ui;
     Note m_Note;
     QvernoteAPI* m_hEvernote;
     shared_ptr<QEnmlReader> enmlReader;
-    QClickableLabel	*clZoomin, *clZoomout, *clNext, *clPrev, *clFullscreen, *clEdit, *clEmail;
+    QClickableLabel	*clZoomin, *clZoomout, *clNext, *clPrev, *clFullscreen, *clEdit, *clEmail, *clMap;
     QTimer* navigationControlTimer;
     QPoint	mousePos;
     bool isMousePressed;
@@ -132,4 +141,21 @@ bool QWebViewEventFilter::eventFilter(QObject *, QEvent *e)
  return false;
 };
 
+class QResourceHandlerDialog : public QDialog
+{
+	Q_OBJECT
+
+public:
+	QResourceHandlerDialog(Note& note, QString resourceHash, QWidget* parent = 0);
+
+public slots:
+	void storeResource();
+    void previewResource();
+
+private:
+    Note m_Note;
+    QString m_resourceHash;
+	QGridLayout* layout;
+	QPushButton bSave, bPreview;
+};
 #endif // QNOTEVIEWWINDOW_H
