@@ -38,11 +38,11 @@ QNotesView::QNotesView(const Notebook& notebook, QWidget *parent)
 
 	QActionGroup *noteSortGroup = new QActionGroup(this);
 	noteSortGroup->setExclusive(true);
-	QAction* actAscending = new QAction("Oldest first", noteSortGroup);
+	QAction* actAscending = new QAction(trUtf8("Oldest first"), noteSortGroup);
 	actAscending->setCheckable(true);
 
 	actAscending->setChecked((QvernoteSettings::Instance()->getNoteDisplayOrder() == QvernoteSettings::NDO_ASC));
-	QAction* actDescending = new QAction("Newest first", noteSortGroup);
+	QAction* actDescending = new QAction(trUtf8("Newest first"), noteSortGroup);
 	actDescending->setCheckable(true);
 	actDescending->setChecked((QvernoteSettings::Instance()->getNoteDisplayOrder() == QvernoteSettings::NDO_DESC));
 
@@ -63,7 +63,7 @@ QNotesView::QNotesView(const Notebook& notebook, QWidget *parent)
 
 	setProgressIndicator(true);
 	reloadNotes();
-	displayInformationBox("Loading notes. Please wait...");
+	displayInformationBox(trUtf8("Loading notes. Please wait..."));
 }
 
 
@@ -98,7 +98,7 @@ QNotesView::QNotesView(QString windowTitle, QWidget *parent)
 	ui.gridLayout->addWidget(m_pKeyGrabber.get(), 2, 0);
 
 	setProgressIndicator(true);
-	displayInformationBox("Loading notes. Please wait...");
+	displayInformationBox(trUtf8("Loading notes. Please wait..."));
 	loadNotesIntoView();
 }
 
@@ -139,7 +139,7 @@ void QNotesView::getNextNote(Note& nextNote)
 {
 	if(m_pNoteListViewWidget->nextNote(nextNote) == false)
 	{
-		displayInformationBox("This is the last note");
+		displayInformationBox(trUtf8("This is the last note"));
 	}
 }
 
@@ -147,7 +147,7 @@ void QNotesView::getPrevNote(Note& prevNote)
 {
 	if(m_pNoteListViewWidget->prevNote(prevNote) == false)
 	{
-		displayInformationBox("This is the first note");
+		displayInformationBox(trUtf8("This is the first note"));
 	}
 }
 
@@ -159,7 +159,7 @@ void QNotesView::loadDeleteNotesView()
 
 void QNotesView::notesViewShutdown()
 {
-	displayError("Error loading notebook", QString(m_hEvernote->getLastErrorString().c_str()));
+	displayError(trUtf8("Error loading notebook"), QString(m_hEvernote->getLastErrorString().c_str()));
 	close();
 }
 
@@ -173,7 +173,7 @@ bool QNotesView::queryNotes()
 
 void QNotesView::clearNote(Note& m_Note)
 {
-	//qDebug() << "Delete note content";
+	//qDebug() << trUtf8("Delete note content");
 
 	m_Note.content.clear();
 	m_Note.content.reserve(0);
@@ -226,6 +226,7 @@ void QNotesView::onNoteLoadDone()
 
 void QNotesView::orientationChanged()
 {
+	while(isSynchronizing)
 	loadNotesIntoView();
 }
 
