@@ -42,6 +42,11 @@ public:
 		NDO_DESC
 	};
 
+	enum MapsProvider {
+		MP_OVI,
+		MP_GOOGLE
+	};
+
 	static QvernoteSettings* Instance()
 	{
 		if(settings == NULL)
@@ -60,6 +65,7 @@ public:
 	CONFIG_VAR(bool, WorkOnline);
 	CONFIG_VAR(NotesView, NotesView);
 	CONFIG_VAR(NoteDisplayOrder, NoteDisplayOrder);
+	CONFIG_VAR(MapsProvider, MapsProvider);
 public:
 	void 	Store();
 	void	Load();
